LocationService class

Helper for requesting location permission and reading the current coordinates as LatLong.

Constructors

LocationService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

ensurePermission() Future<bool>
Ensures that location services are enabled and permission was granted.
getCurrentPosition() Future<LatLong?>
Returns the current coordinates when permission is granted.